Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
licenzy\__init__.py | (no function) | 4 | 0 | 0 | 100%
licenzy\cli.py | main | 1 | 1 | 0 | 0%
licenzy\cli.py | activate | 3 | 3 | 0 | 0%
licenzy\cli.py | deactivate | 1 | 1 | 0 | 0%
licenzy\cli.py | status | 1 | 1 | 0 | 0%
licenzy\cli.py | check | 4 | 4 | 0 | 0%
licenzy\cli.py | info | 24 | 24 | 0 | 0%
licenzy\cli.py | (no function) | 19 | 19 | 0 | 0%
licenzy\core.py | LicenseManager.__init__ | 3 | 0 | 0 | 100%
licenzy\core.py | LicenseManager._find_license_key | 10 | 1 | 0 | 90%
licenzy\core.py | LicenseManager.validate_license | 18 | 3 | 0 | 83%
licenzy\core.py | LicenseManager._generate_signature | 3 | 3 | 0 | 0%
licenzy\core.py | LicenseManager.check_license | 8 | 1 | 0 | 88%
licenzy\core.py | LicenseManager._show_license_warning | 12 | 12 | 0 | 0%
licenzy\core.py | LicenseManager.get_license_info | 3 | 3 | 0 | 0%
licenzy\core.py | get_license_manager | 3 | 0 | 0 | 100%
licenzy\core.py | check_license | 1 | 0 | 0 | 100%
licenzy\core.py | licensed | 5 | 0 | 0 | 100%
licenzy\core.py | licensed.decorator | 2 | 0 | 0 | 100%
licenzy\core.py | licensed.decorator.wrapper | 4 | 0 | 0 | 100%
licenzy\core.py | access_granted | 1 | 0 | 0 | 100%
licenzy\core.py | require_key | 1 | 0 | 0 | 100%
licenzy\core.py | unlock | 1 | 0 | 0 | 100%
licenzy\core.py | (no function) | 24 | 0 | 0 | 100%
licenzy\management.py | activate_license | 13 | 13 | 0 | 0%
licenzy\management.py | deactivate_license | 6 | 6 | 0 | 0%
licenzy\management.py | show_license_status | 20 | 20 | 0 | 0%
licenzy\management.py | get_license_key_location | 2 | 2 | 0 | 0%
licenzy\management.py | (no function) | 7 | 0 | 0 | 100%
Total |  | 204 | 117 | 0 | 43%

No items found using the specified filter.